---
title: Study Locus
---

::: gentropy.dataset.study_locus.StudyLocus

---

::: gentropy.dataset.study_locus.FinemappingMethod

---

::: gentropy.dataset.study_locus.StudyLocusQualityCheck

---

::: gentropy.dataset.study_locus.CredibleInterval

## Schema

--8<-- "assets/schemas/study_locus.md"
